==> exonmap_1.0.07.tar.gz: exonmap/man/splanova.Rd <==
\name{splanova}
\alias{splanova}
\alias{fval}
\alias{sig}

\title{ Find probesets involved in differential splicing for multiple treatments}
\description{
 Reads expression data and using its \code{\link[Biobase]{pData}} 
 calculates F-values and finds significant cases using ANOVA. 
 The approach is similar to MIDAS, described in Affymetrix white 
 paper "Alternative Transcript Analysis Methods for Exon Arrays".
}
\usage{
splanova (x,genesin, group,base, thr=0.05, probes.min=4, exonic=T, debug=0)
fval(object)
sig(object)
}

\arguments{
  \item{x}{eSet for which splicing is to be calculated }
  \item{genesin}{ Vector of Ensembl gene names to check }
  \item{group}{ Group name from covdesc }
  \item{base}{ Reference treatment name for the one-way ANOVA model - must be in the group in covdesc }
  \item{thr}{ Alpha level threshold for F-test }
  \item{probes.min}{ Minimal number of probes to include the probeset in the search - see \code{\link[exonmap]{gene.to.probeset}}}
  \item{exonic}{ Specifies if only exonic probesets should be used - see \code{\link[exonmap]{select.probewise}}}
  \item{debug}{ Debug level - 0 stands for no debug messages }
  \item{object}{ a splanova object of class \code{Splanova}}
}
\details{ }
\value{
  A Splanova object with two slots : fval - list of F-values from ANOVA and sig - descriptive 
  listing of splicing events. 
}
\references{\url{ http://bioinformatics.picr.man.ac.uk/}}
\author{ Michal J Okoniewski }

\seealso{\code{\link[exonmap]{splicing.index}}, code{\link[exonmap]{gene.to.probeset}}, \code{\link[exonmap]{select.probewise}}, \code{\link[Biobase]{pData}  }}
\keyword{ misc }
\examples{ 
  \dontrun{
    gg <- probeset.to.gene(c("2326780","2326822" ))
    spl.multi <-  splanova(x.rma, gg, "group", "a", thr=0.05, debug=4)
    fval(spl.multi)
    sig(spl.multi)
  }
}

==> exonmap_1.4.3.tar.gz: exonmap/man/splanova.Rd <==
\name{splanova}
\alias{splanova}
\alias{fval}
\alias{sig}

\title{ Find probesets involved in differential splicing for multiple treatments}
\description{
 Reads expression data and using its \code{\link[Biobase]{pData}} 
 calculates F-values and finds significant cases using ANOVA. 
 The approach is similar to MIDAS, described in Affymetrix white 
 paper "Alternative Transcript Analysis Methods for Exon Arrays".
}
\usage{
splanova (x,genesin, group,base, thr=0.05, probes.min=4, exonic=TRUE)
fval(object)
sig(object)
}

\arguments{
  \item{x}{eSet for which splicing is to be calculated }
  \item{genesin}{ Vector of Ensembl gene names to check }
  \item{group}{ Group name from covdesc }
  \item{base}{ Reference treatment name for the one-way ANOVA model - must be in the group in covdesc }
  \item{thr}{ Alpha level threshold for F-test }
  \item{probes.min}{ Minimal number of probes to include the probeset in the search - see \code{\link[exonmap]{gene.to.probeset}}}
  \item{exonic}{ Specifies if only exonic probesets should be used - see \code{\link[exonmap]{select.probewise}}}
  \item{object}{ a splanova object of class \code{Splanova}}
}
\details{ }
\value{
  A Splanova object with two slots : fval - list of F-values from ANOVA and sig - descriptive 
  listing of splicing events. 
}
\references{\url{ http://bioinformatics.picr.man.ac.uk/}}
\author{ Michal J Okoniewski }

\seealso{\code{\link[exonmap]{splicing.index}}, code{\link[exonmap]{gene.to.probeset}}, \code{\link[exonmap]{select.probewise}}, \code{\link[Biobase]{pData}  }}
\keyword{ misc }
\examples{ 
  \dontrun{
    gg <- probeset.to.gene(c("2326780","2326822" ))
    spl.multi <-  splanova(x.rma, gg, "group", "a", thr=0.05)
    fval(spl.multi)
    sig(spl.multi)
  }
}
